@@ -1,6 +1,6 @@
 .onLoad <- function(libname, pkgname) {
 
-.jinit(parameters="-XmX512m",force.init=TRUE)
+.jinit(parameters="-Xmx512m",force.init=TRUE)
 .jpackage(pkgname)
   
 }  
